    Для работы необходимо установить python не ниже версии 3.7.

    Библиотека принимает е-мэйл и пароль от аккаунта дискорда и
    возвращает токен. Возможно использование прокси.
    Автоматически проходит капчу если она требуется.
    Автоматически разрешает вход с нового ip-адреса через почту, если
    в настройках почтового ящика включена функция:
    "Разрешить доступ к почтовому ящику с помощью почтовых клиентов"

![img.png](img.png)

    Для работы с капчей необходимо:
    1. Зарегистрироваться на сайте https://anti-captcha.com/
    2. Купить ключ для работы с API.
    3. Прописать ключ в файле .env в поле
        ANTICAPTCHA_KEY="здесь_должен_быть_ключ"

    Для работы через прокси нужно прописать в файле .env следующие поля:
        PROXY_IP="111.111.111.111"
        PROXY_PORT="1234"
        PROXY_USER="логин_от_прокси"
        PROXY_PASSWORD="пароль_от_прокси"

    Запуск осуществляется командой
        python main.py
    из папки с этим файлом и файлом настроек .env


[Видео запуска](https://youtu.be/EfiZhA0_8zs)
